MapLayerZ class abstract final

Canonical Z-order for the six-layer map composition model.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(MapLayerType layer) int

Constants

baseTile → const int
fleet → const int
hazard → const int
route → const int
safety → const int
weather → const int
z0 → const int
z1 → const int
z2 → const int
z3 → const int
z4 → const int
z5 → const int